==> haskell-some-1.0.5-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-some.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 some
version:              1.0.5
visibility:           public
id:                   some-1.0.5-L5glA67mR8RJufLDsA2lRz
key:                  some-1.0.5-L5glA67mR8RJufLDsA2lRz
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    James Cook <mokus@deepbondi.net>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/some
synopsis:             Existential type: Some
description:
    This library defines an existential type '\''Some'\''.

    @
    data Some f where
    \    Some :: f a -> Some f
    @

    in few variants, and utilities to work with it.

    If you are unsure which variant to use, use the one in "Data.Some" module.

category:             Data, Dependent Types
abi:                  fcb5f2f0df1ac043f3e940285b9cf99f
exposed:              True
exposed-modules:
    Data.EqP Data.GADT.Compare Data.GADT.DeepSeq Data.GADT.Show
    Data.OrdP Data.Some Data.Some.Church Data.Some.GADT
    Data.Some.Newtype

hidden-modules:       Data.GADT.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/some-1.0.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/some-1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-some
hs-libraries:         HSsome-1.0.5-L5glA67mR8RJufLDsA2lRz
depends:              base-4.16.4.0 deepseq-1.4.6.1
haddock-interfaces:   /usr/share/doc/haskell-some/html/some.haddock
haddock-html:         /usr/share/doc/haskell-some/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-some-1.0.6-1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-some.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 some
version:              1.0.6
visibility:           public
id:                   some-1.0.6-33UPTY2v022DFo5SyHLB0b
key:                  some-1.0.6-33UPTY2v022DFo5SyHLB0b
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    James Cook <mokus@deepbondi.net>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/some
synopsis:             Existential type: Some
description:
    This library defines an existential type '\''Some'\''.

    @
    data Some f where
    \    Some :: f a -> Some f
    @

    in few variants, and utilities to work with it.

    If you are unsure which variant to use, use the one in "Data.Some" module.

category:             Data, Dependent Types
abi:                  870c85a883a6ad9b3b0063f15e0aa3ae
exposed:              True
exposed-modules:
    Data.EqP Data.GADT.Compare Data.GADT.DeepSeq Data.GADT.Show
    Data.OrdP Data.Some Data.Some.Church Data.Some.GADT
    Data.Some.Newtype

hidden-modules:       Data.GADT.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/some-1.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/some-1.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/some-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-some
hs-libraries:         HSsome-1.0.6-33UPTY2v022DFo5SyHLB0b
depends:
    base-4.17.2.1 base-orphans-0.9.1-H5ZKrdj0NFhGxOpdRcZ2du
    deepseq-1.4.8.0

haddock-interfaces:   /usr/share/doc/haskell-some/html/some.haddock
haddock-html:         /usr/share/doc/haskell-some/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
